@@ -5,7 +5,7 @@
  * pgpool: a language independent connection pool server for PostgreSQL
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003-2023	PgPool Global Development Group
+ * Copyright (c) 2003-2019	PgPool Global Development Group
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -259,6 +259,16 @@ get_config(int *nrows)
 	StrNCpy(status[i].desc, "Use server's SSL cipher preferences", POOLCONFIG_MAXDESCLEN);
 	i++;
 
+	StrNCpy(status[i].name, "ssl_ecdh_curve", POOLCONFIG_MAXNAMELEN);
+	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s", pool_config->ssl_ecdh_curve);
+	StrNCpy(status[i].desc, "the curve to use in ECDH key exchange", POOLCONFIG_MAXDESCLEN);
+	i++;
+
+	StrNCpy(status[i].name, "ssl_dh_params_file", POOLCONFIG_MAXNAMELEN);
+	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s", pool_config->ssl_dh_params_file);
+	StrNCpy(status[i].desc, "path to the Diffie-Hellman parameters contained file", POOLCONFIG_MAXDESCLEN);
+	i++;
+
 	/* POOLS */
 
 	/* - Pool size -  */
@@ -277,6 +287,11 @@ get_config(int *nrows)
 	StrNCpy(status[i].desc, "whether to serialize accept() call", POOLCONFIG_MAXDESCLEN);
 	i++;
 
+	StrNCpy(status[i].name, "reserved_connections", POOLCONFIG_MAXNAMELEN);
+	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->reserved_connections);
+	StrNCpy(status[i].desc, "number of reserved connections", POOLCONFIG_MAXDESCLEN);
+	i++;
+
 	StrNCpy(status[i].name, "max_pool", POOLCONFIG_MAXNAMELEN);
 	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->max_pool);
 	StrNCpy(status[i].desc, "max # of connection pool per child", POOLCONFIG_MAXDESCLEN);
@@ -494,6 +509,11 @@ get_config(int *nrows)
 	StrNCpy(status[i].desc, "Load balance behavior when write query is received", POOLCONFIG_MAXDESCLEN);
 	i++;
 
+	StrNCpy(status[i].name, "statement_level_load_balance", POOLCONFIG_MAXNAMELEN);
+	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->statement_level_load_balance);
+	StrNCpy(status[i].desc, "statement level load balancing", POOLCONFIG_MAXDESCLEN);
+	i++;
+
 	/* MASTER/SLAVE MODE */
 
 	StrNCpy(status[i].name, "master_slave_mode", POOLCONFIG_MAXNAMELEN);
@@ -617,6 +637,16 @@ get_config(int *nrows)
 	StrNCpy(status[i].desc, "detach false primary", POOLCONFIG_MAXDESCLEN);
 	i++;
 
+	StrNCpy(status[i].name, "auto_failback", POOLCONFIG_MAXNAMELEN);
+	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->auto_failback);
+	StrNCpy(status[i].desc, "auto_failback", POOLCONFIG_MAXDESCLEN);
+	i++;
+
+	StrNCpy(status[i].name, "auto_failback_interval", POOLCONFIG_MAXNAMELEN);
+	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->auto_failback_interval);
+	StrNCpy(status[i].desc, "auto_failback_interval", POOLCONFIG_MAXDESCLEN);
+	i++;
+
 	/* ONLINE RECOVERY */
 
 	StrNCpy(status[i].name, "recovery_user", POOLCONFIG_MAXNAMELEN);
@@ -671,6 +701,16 @@ get_config(int *nrows)
 	StrNCpy(status[i].desc, "enable unlogged table check", POOLCONFIG_MAXDESCLEN);
 	i++;
 
+	StrNCpy(status[i].name, "enable_shared_relcache", POOLCONFIG_MAXNAMELEN);
+	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->enable_shared_relcache);
+	StrNCpy(status[i].desc, "If true, relation cache stored in memory cache", POOLCONFIG_MAXDESCLEN);
+	i++;
+
+	StrNCpy(status[i].name, "relcache_query_target", POOLCONFIG_MAXNAMELEN);
+	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%d", pool_config->relcache_query_target);
+	StrNCpy(status[i].desc, "Target node to send relcache queries", POOLCONFIG_MAXDESCLEN);
+	i++;
+
 	/*
 	 * add for watchdog
 	 */
@@ -799,12 +839,10 @@ get_config(int *nrows)
 	StrNCpy(status[i].desc, "watchdog user monitoring pgpools in lifecheck", POOLCONFIG_MAXDESCLEN);
 	i++;
 
-#ifdef NOT_USED					/* for security reason */
 	StrNCpy(status[i].name, "wd_lifecheck_password", POOLCONFIG_MAXNAMELEN);
 	snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s", pool_config->wd_lifecheck_password);
 	StrNCpy(status[i].desc, "password for watchdog user in lifecheck", POOLCONFIG_MAXDESCLEN);
 	i++;
-#endif
 
 	StrNCpy(status[i].name, "wd_monitoring_interfaces_list", POOLCONFIG_MAXNAMELEN);
 	*(status[i].value) = '\0';
@@ -960,6 +998,11 @@ get_config(int *nrows)
 		snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s", pool_flag_to_str(BACKEND_INFO(j).flag));
 		snprintf(status[i].desc, POOLCONFIG_MAXDESCLEN, "backend #%d flag", j);
 		i++;
+
+		snprintf(status[i].name, POOLCONFIG_MAXNAMELEN, "backend_application_name%d", j);
+		snprintf(status[i].value, POOLCONFIG_MAXVALLEN, "%s", BACKEND_INFO(j).backend_application_name);
+		snprintf(status[i].desc, POOLCONFIG_MAXDESCLEN, "application_name for backend #%d", j);
+		i++;
 	}
 
 	for (j = 0; j < MAX_WATCHDOG_NUM; j++)
@@ -1187,6 +1230,9 @@ config_reporting(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * backend)
 	pfree(status);
 }
 
+/*
+ * for SHOW pool_nodes
+ */
 POOL_REPORT_NODES *
 get_nodes(int *nrows)
 {
@@ -1234,6 +1280,10 @@ get_nodes(int *nrows)
 		/* status last changed */
 		localtime_r(&bi->status_changed_time, &tm);
 		strftime(nodes[i].last_status_change, POOLCONFIG_MAXDATELEN, "%F %T", &tm);
+
+		/* from pg_stat_replication */
+		snprintf(nodes[i].rep_state, POOLCONFIG_MAXWEIGHTLEN, "%s", bi->replication_state);
+		snprintf(nodes[i].rep_sync_state, POOLCONFIG_MAXWEIGHTLEN, "%s", bi->replication_sync_state);
 	}
 
 	*nrows = i;
@@ -1241,10 +1291,13 @@ get_nodes(int *nrows)
 	return nodes;
 }
 
+/*
+ * SHOW pool_nodes;
+ */
 void
 nodes_reporting(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * backend)
 {
-	static char *field_names[] = {"node_id", "hostname", "port", "status", "lb_weight", "role", "select_cnt", "load_balance_node", "replication_delay", "last_status_change"};
+	static char *field_names[] = {"node_id", "hostname", "port", "status", "lb_weight", "role", "select_cnt", "load_balance_node", "replication_delay", "replication_state", "replication_sync_state", "last_status_change"};
 	short		num_fields = sizeof(field_names) / sizeof(char *);
 	int			i;
 	short		s;
@@ -1312,6 +1365,16 @@ nodes_reporting(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * backend)
 			pool_write(frontend, &hsize, sizeof(hsize));
 			pool_write(frontend, nodes[i].delay, size);
 
+			size = strlen(nodes[i].rep_state);
+			hsize = htonl(size + 4);
+			pool_write(frontend, &hsize, sizeof(hsize));
+			pool_write(frontend, nodes[i].rep_state, size);
+
+			size = strlen(nodes[i].rep_sync_state);
+			hsize = htonl(size + 4);
+			pool_write(frontend, &hsize, sizeof(hsize));
+			pool_write(frontend, nodes[i].rep_sync_state, size);
+
 			size = strlen(nodes[i].last_status_change);
 			hsize = htonl(size + 4);
 			pool_write(frontend, &hsize, sizeof(hsize));
@@ -1334,6 +1397,8 @@ nodes_reporting(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * backend)
 			len += 4 + strlen(nodes[i].select); /* int32 + data; */
 			len += 4 + strlen(nodes[i].load_balance_node);	/* int32 + data; */
 			len += 4 + strlen(nodes[i].delay);	/* int32 + data; */
+			len += 4 + strlen(nodes[i].rep_state);	/* int32 + data; */
+			len += 4 + strlen(nodes[i].rep_sync_state);	/* int32 + data; */
 			len += 4 + strlen(nodes[i].last_status_change); /* int32 + data; */
 			len = htonl(len);
 			pool_write(frontend, &len, sizeof(len));
@@ -1376,6 +1441,14 @@ nodes_reporting(POOL_CONNECTION * frontend, POOL_CONNECTION_POOL * backend)
 			pool_write(frontend, &len, sizeof(len));
 			pool_write(frontend, nodes[i].delay, strlen(nodes[i].delay));
 
+			len = htonl(strlen(nodes[i].rep_state));
+			pool_write(frontend, &len, sizeof(len));
+			pool_write(frontend, nodes[i].rep_state, strlen(nodes[i].rep_state));
+
+			len = htonl(strlen(nodes[i].rep_sync_state));
+			pool_write(frontend, &len, sizeof(len));
+			pool_write(frontend, nodes[i].rep_sync_state, strlen(nodes[i].rep_sync_state));
+
 			len = htonl(strlen(nodes[i].last_status_change));
 			pool_write(frontend, &len, sizeof(len));
 			pool_write(frontend, nodes[i].last_status_change, strlen(nodes[i].last_status_change));
