@@ -1018,16 +1018,22 @@ non_immutable_function_call_walker(Node *node, void *context)
 			}
 		}
 	}
+
+	/* Before Pgpool-II 3.7 there was no SQLValueFunction in the parser.  For
+	 * the older versions (3.6 or before), we need to check type cast and
+	 * typename instead.  If they are some type casts described below, we
+	 * assume that this SELECT cannot be cached since they might be a
+	 * transformed CURRENT_TIMESTAMP etc.  Of course this could be overkill as
+	 * "SELECT '2022-07-04 09:00:00'::TIMESTAMP" could be regarded as
+	 * non-cachable for example. But there's nothing we can do here.
+	 */
 	else if (IsA(node, TypeCast))
 	{
-		/* CURRENT_DATE, CURRENT_TIME, LOCALTIMESTAMP, LOCALTIME etc. */
+		/* TIMESTAMP WITH TIME ZONE and TIME WITH TIME ZONE should not be cached. */
 		TypeCast   *tc = (TypeCast *) node;
 
-		if ((isSystemType((Node *) tc->typeName, "date") ||
-			 isSystemType((Node *) tc->typeName, "timestamp") ||
-			 isSystemType((Node *) tc->typeName, "timestamptz") ||
-			 isSystemType((Node *) tc->typeName, "time") ||
-			 isSystemType((Node *) tc->typeName, "timetz")))
+		if (isSystemType((Node *) tc->typeName, "timestamptz") ||
+			isSystemType((Node *) tc->typeName, "timetz"))
 		{
 			ctx->has_non_immutable_function_call = true;
 			return false;
